package com.plannaplan.services;

import java.util.List;
import java.util.Optional;

import com.plannaplan.entities.Assignment;
import com.plannaplan.entities.Exchange;
import com.plannaplan.entities.Groups;
import com.plannaplan.repositories.ExchangeRepository;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class ExchangeService {
    
    @Autowired
    private ExchangeRepository repo;

    /** 
     * @param exchange Instance to save in database
     * @return Exchange Instance contains database id
     */
    public Exchange save(Exchange exchange){
        return this.repo.save(exchange);
    }
 
    /** 
     * @param id Id of exchange in database
     * @return Optional Exchange if found
     */
    public Optional<Exchange> getById(Long id){
        return this.repo.findById(id);
    } 
    
    /** 
     * @param id Id of user
     * @return List of exchanges that belong to user
     */
    public List<Exchange> getByUserId(Long id){
        return this.repo.getByUserId(id);
    } 

    /** 
     * @param entity Exchange entity which we would like to delete
     */
    public void deleteExchange(Exchange entity){
        this.repo.delete(entity);
    }

    /** 
     * @param assignment Assignment to trade for
     * @param group Desired group
     * @return Optional with Exchange if exist
     */
    public Optional<Exchange> checkForExchange(Assignment assignment, Groups group){
        return this.repo.checkForExchange(assignment, group);
    }
}
